@@ -1,5 +1,5 @@
 package Bio::Tradis::CommandLine::TradisAnalysis;
-$Bio::Tradis::CommandLine::TradisAnalysis::VERSION = '1.2.4';
+$Bio::Tradis::CommandLine::TradisAnalysis::VERSION = '1.3.0';
 # ABSTRACT: Perform full tradis analysis
 
 
@@ -24,6 +24,8 @@ has 'smalt_k' => ( is => 'rw', isa => 'Maybe[Int]', required => 0 );
 has 'smalt_s' => ( is => 'rw', isa => 'Maybe[Int]', required => 0 );
 has 'smalt_y' => ( is => 'rw', isa => 'Maybe[Num]', required => 0, default => 0.96 );
 has 'smalt_r' => ( is => 'rw', isa => 'Maybe[Int]', required => 0, default => -1 );
+has 'smalt_n' => ( is => 'rw', isa => 'Maybe[Int]', required => 0, default => 1 );
+has 'essentiality' => ( is => 'rw', isa => 'Bool',  required => 0, default => 0);
 
 has 'verbose' => ( is => 'rw', isa => 'Bool', default => 0 );
 has 'samtools_exec' => ( is => 'rw', isa => 'Str', default => 'samtools' );
@@ -48,7 +50,7 @@ sub BUILD {
     my ($self) = @_;
 
     my (
-        $fastqfile, $tag,     $td,      $mismatch, $ref,
+        $fastqfile, $tag,     $td,      $mismatch, $ref,$smalt_n, $essentiality,
         $map_score, $smalt_k, $smalt_s, $smalt_y, $smalt_r, $help, $verbose,$samtools_exec
     );
 
@@ -63,12 +65,22 @@ sub BUILD {
         'sk|smalt_k=i'      => \$smalt_k,
         'ss|smalt_s=i'      => \$smalt_s,
         'sy|smalt_y=f'      => \$smalt_y,
-	'sr|smalt_r=i'      => \$smalt_r,
+				'n|smalt_n=i'       => \$smalt_n,
+	      'sr|smalt_r=i'      => \$smalt_r,
         'v|verbose'         => \$verbose,
         'samtools_exec=s'   => \$samtools_exec,
+				'e|essentiality'    => \$essentiality,
         'h|help'            => \$help
     );
 
+    #Essentiality analysis requires different defaults.
+    if(!defined($smalt_r) && !defined($map_score) && defined($essentiality))
+		{
+       $self->essentiality($essentiality)   if ( defined($essentiality));
+			 $smalt_r = 0;
+			 $map_score = 0;
+    }
+
     $self->fastqfile( abs_path($fastqfile) ) if ( defined($fastqfile) );
     $self->tag( uc($tag) )                   if ( defined($tag) );
     $self->tagdirection($td)                 if ( defined($td) );
@@ -78,12 +90,12 @@ sub BUILD {
     $self->smalt_k($smalt_k)                 if ( defined($smalt_k) );
     $self->smalt_s($smalt_s)                 if ( defined($smalt_s) );
     $self->smalt_y($smalt_y)                 if ( defined($smalt_y) );
-    $self->smalt_r($smalt_r)		     if ( defined($smalt_r) );
+    $self->smalt_r($smalt_r)		             if ( defined($smalt_r) );
+		$self->smalt_n($smalt_n)		             if ( defined($smalt_n) );
     $self->help($help)                       if ( defined($help) );
     $self->verbose($verbose)                 if ( defined($verbose));
     $self->samtools_exec($samtools_exec)     if ( defined($samtools_exec) );
     
-
     # print usage text if required parameters are not present
     ( $fastqfile && $tag && $ref ) or die $self->usage_text;
 }
@@ -135,6 +147,7 @@ sub run {
             smalt_s          => $self->smalt_s,
             smalt_y          => $self->smalt_y,
             smalt_r          => $self->smalt_r,
+						smalt_n          => $self->smalt_n,
             verbose          => $self->verbose,
             samtools_exec    => $self->samtools_exec
         );
@@ -240,6 +253,8 @@ Options:
 --smalt_s : custom step size for SMALT mapping (optional)
 --smalt_y : custom y parameter for SMALT (optional. default = 0.96)
 --smalt_r : custom r parameter for SMALT (optional. default = -1)
+-n        : number of threads to use for SMALT and samtools sort (optional. default = 1)
+-e        : set defaults for essentiality experiment (smalt_r = 0, -m = 0)
 -v        : verbose debugging output
 USAGE
     exit;
@@ -261,7 +276,7 @@ Bio::Tradis::CommandLine::TradisAnalysis - Perform full tradis analysis
 
 =head1 VERSION
 
-version 1.2.4
+version 1.3.0
 
 =head1 SYNOPSIS
 
